netapp_ontap.models.cluster_peer_setup API documentation
Description: Copyright &copy; 2020 NetApp Inc. All rights reserved.

# Module `netapp_ontap.models.cluster_peer_setup`

Copyright © 2020 NetApp Inc. All rights reserved.

## Classes

`class ClusterPeerSetupSchema (*, only: typing.Union = None, exclude: typing.Union = (), many: bool = False, context: typing.Dict = None, load_only: typing.Union = (), dump_only: typing.Union = (), partial: typing.Union = False, unknown: str = None)`

  The fields of the ClusterPeerSetup object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC

  ### Class variables

  `authentication GET POST PATCH`

    The authentication field of the cluster_peer_setup.

  `ip_address GET POST PATCH`

    A local intercluster IP address that a remote cluster can use, together with the passphrase, to create a cluster peer relationship with the local cluster.

  `links GET`

    The links field of the cluster_peer_setup.

  `name GET POST PATCH`

    Optional name for the cluster peer relationship. By default, it is the name of the remote cluster, or a temporary name might be autogenerated for anonymous cluster peer offers.

    Example: cluster2